@@ -77,19 +77,23 @@ fill_na.tbl_ts <- function(.data, ...) {
     )
 
   if (is_grouped_ts(.data)) {
-    full_data <- do(full_data, modify_na(., !!! quos(...)))
+    full_data <- do(full_data, modify_na(., !!! enquos(...)))
   } else {
     full_data <- full_data %>%
-      modify_na(!!! quos(...))
+      modify_na(!!! enquos(...))
   }
   full_data <- full_data %>%
     select(!!! syms(colnames(.data))) # keep the original order
-  tsbl <- as_tsibble(full_data, key = key, index = !! idx, validate = FALSE)
+  # ensure the time ordering
+  tsbl <- build_tsibble(
+    full_data, key = key, index = !! idx, 
+    validate = FALSE, ordered = NULL
+  )
   restore_index_class(.data, tsbl)
 }
 
 modify_na <- function(.data, ...) {
-  lst_quos <- quos(..., .named = TRUE)
+  lst_quos <- enquos(..., .named = TRUE)
   if (is_empty(lst_quos)) {
     return(.data)
   }
@@ -97,14 +101,14 @@ modify_na <- function(.data, ...) {
   check_names <- lhs %in% colnames(.data)
   if (is_false(all(check_names))) {
     bad_names <- paste_comma(lhs[which(!check_names)])
-    abort(sprintf("Can't find column %s in `.data`.", surround(bad_names, "`")))
+    abort(sprintf("Can't find column `%s` in `.data`.", bad_names))
   }
 
   rhs <- purrr::map(lst_quos, f_rhs)
   lst_lang <- purrr::map2(
     syms(lhs), rhs, ~ new_formula(.x, .y, env = env(!!! .data))
   )
-  mod_quos <- purrr::map(lst_lang, ~ lang("case_na", .))
+  mod_quos <- purrr::map(lst_lang, ~ call2("case_na", .))
   names(mod_quos) <- lhs
   modify_na_handler(.data, mod_quos)
 }
