@@ -18,21 +18,21 @@
   # subset by columns
   if (!missing(j)) {
     chr_j <- validate_vars(j, colnames(x))
-    lgl_j <- has_index_var(chr_j, x) && has_reduce_key(chr_j, x)
+    lgl_j <- has_index_var(chr_j, x) && has_distinct_key(chr_j, x)
     if (is_false(lgl_j)) {
       return(NextMethod())
     }
     result <- .subset(x, j)
-    key(x) <- update_key(key(x), chr_j)
+    x <- key_reduce(x, chr_j)
   }
 
   if (!missing(i)) {
     result <- purrr::map(result, `[`, i)
   }
 
-  as_tsibble(
+  build_tsibble(
     result, key = key(x), index = !! index(x),
-    validate = TRUE, regular = is_regular(x)
+    validate = FALSE, regular = is_regular(x), ordered = is_ordered(x)
   )
 }
 
@@ -45,35 +45,41 @@ has_index <- function(x) {
 # this function usually follows validate_vars()
 has_index_var <- function(j, x) {
   has_index(x)
-  index <- f_text(index(x))
+  index <- as.character(index(x))
   index %in% j
 }
 
-has_reduce_key <- function(j, x) {
-  key_vars <- flatten_key(reduce_key(key(x)))
+has_distinct_key <- function(j, x) {
+  key_vars <- key_flatten(key_distinct(key(x)))
   all(key_vars %in% j)
 }
 
 has_all_key <- function(j, x) {
-  key_vars <- flatten_key(key(x))
+  key_vars <- key_flatten(key(x))
   all(key_vars %in% j)
 }
 
 has_any_key <- function(j, x) {
-  key_vars <- flatten_key(key(x))
+  key_vars <- key_flatten(key(x))
   any(key_vars %in% j)
 }
 
-update_index <- function(x, rhs, lhs) {
-  as_quosure(sym(update_index_name(x, rhs, lhs)))
-}
-
-update_index_name <- function(x, rhs, lhs) {
-  idx_name <- quo_text2(x)
-  idx_idx <- match(idx_name, rhs)
-  new_idx_name <- lhs[idx_idx]
-  if (is.na(idx_idx)) {
-    new_idx_name <- idx_name
+index_rename <- function(.data, ...) {
+  quos <- enquos(...)
+  idx <- index(.data)
+  rhs <- purrr::map_chr(quos, quo_get_expr)
+  lhs <- names(rhs)
+  idx_chr <- quo_text2(idx)
+  idx_pos <- match(idx_chr, rhs)
+  new_idx_chr <- lhs[idx_pos]
+  if (is.na(idx_pos)) {
+    new_idx_chr <- idx_chr
   }
-  new_idx_name # character
+  dat_idx_pos <- match(idx_chr, names(.data))
+  names(.data)[dat_idx_pos] <- new_idx_chr
+  build_tsibble(
+    .data, key = key(.data), index = !! sym(new_idx_chr), 
+    regular = is_regular(.data), validate = FALSE, 
+    ordered = is_ordered(.data), interval = interval(.data)
+  )
 }
