@@ -30,6 +30,9 @@ tbl_sum.tbl_ts <- function(x) {
 #' @export
 tbl_sum.grouped_ts <- function(x) {
   n_grps <- big_mark(n_groups(x))
+  if (has_length(n_grps, 0)) {
+    n_grps <- "?"
+  }
   c(NextMethod(),
     "Groups" = paste(paste_comma(group_vars(x)), surround(n_grps, "["))
   )
