@@ -30,3 +30,22 @@ test_that("Test pillar methods", {
 
   expect_equal(type_sum(pedestrian), "tsibble")
 })
+
+tbl1 <- tsibble(
+  date = seq(as.Date("2017-01-01"), as.Date("2017-01-10"), by = 1),
+  value = rnorm(10),
+  key = id(), index = date
+)
+tbl2 <- tsibble(
+  qtr = rep(yearquarter(seq(2010, 2012.25, by = 1 / 4)), 3),
+  group = rep(c("x", "y", "z"), each = 10),
+  value = rnorm(30),
+  key = id(group), index = qtr
+)
+
+test_that("Test tbl_sum()", {
+  expect_identical(tbl_sum(tbl1), c("A tsibble" = "10 x 2 [1DAY]"))
+  expect_identical(
+    tbl_sum(tbl2), 
+    c("A tsibble" = "30 x 3 [1QUARTER]", "Keys" = "group [3]"))
+})
